Cryptwentyone\[0.2.3\]
=============

Cryptwentyone is a simple python package that provides simple cryptographic and hashing functions. They are written in
pure python and C, so you can take a look at the python code if you want to learn about the algorithms or use the
compiled C code if you want to use the functions in your own programs and have a good performance.

The Package is under development and is not yet ready for use. Support me
by [donating](https://github.com/MPCodeWriter21/cryptwentyone/blob/master/DONATE.md) or by contributing(Fork the repo.
Add your code. Submit a pull request.) or just give this repository a star.

Available Features
------------------

+ Python Implementation of MD5 hashing algorithm
+ Python Implementation of SHA1 hashing algorithm

About
-----
Author: CodeWriter21 (Mehrad Pooryoussof)

GitHub: [MPCodeWriter21](https://github.com/MPCodeWriter21)

Telegram Channel: [@CodeWriter21](https://t.me/CodeWriter21)

Aparat Channel: [CodeWriter21](https://www.aparat.com/CodeWriter21)

### License

![License](https://img.shields.io/github/license/MPCodeWriter21/cryptwentyone)

[apache-2.0](http://www.apache.org/licenses/LICENSE-2.0)

### Donate

In order to support this project you can donate some crypto of your choice 8D

[Donate Addresses](https://github.com/MPCodeWriter21/log21/blob/master/DONATE.md)

Or if you can't, give [this project](https://github.com/MPCodeWriter21/log21) a star on GitHub :)
